@@ -7,6 +7,8 @@ from ..share import constants
 
 class Trigger(object):
 
+    task_class = Task
+
     box_class = None
     client = None
 
@@ -20,7 +22,7 @@ class Trigger(object):
         :param params 指定task的参数, dict类型
         """
 
-        task = Task()
+        task = self.task_class()
         task.cmd = constants.CMD_WRITE_TO_WORKER
 
         if params:
@@ -70,7 +72,7 @@ class Trigger(object):
             if exclude:
                 row.exclude.extend(exclude)
 
-        task = Task()
+        task = self.task_class()
         task.cmd = constants.CMD_WRITE_TO_USERS
         task.body = msg.SerializeToString()
 
@@ -83,7 +85,7 @@ class Trigger(object):
         if exclude:
             msg.exclude.extend(exclude)
 
-        task = Task()
+        task = self.task_class()
         task.cmd = constants.CMD_CLOSE_USERS
         task.body = msg.SerializeToString()
 
