@@ -1,4 +1,3 @@
-from ...share.task import Task
 from ...share.log import logger
 from ...share import constants
 from ...share.proto.maple_pb2 import RspToUsers, CloseUsers
@@ -149,7 +148,7 @@ class Request(object):
             if exclude:
                 row.exclude.extend(exclude)
 
-        task = Task()
+        task = self.app.task_class()
         task.cmd = constants.CMD_WRITE_TO_USERS
         task.body = msg.SerializeToString()
 
@@ -169,7 +168,7 @@ class Request(object):
         if exclude:
             msg.exclude.extend(exclude)
 
-        task = Task()
+        task = self.app.task_class()
         task.cmd = constants.CMD_CLOSE_USERS
         task.body = msg.SerializeToString()
 
@@ -197,7 +196,7 @@ class Request(object):
         :param params 指定task的参数, dict类型
         """
 
-        task = Task()
+        task = self.app.task_class()
         task.cmd = constants.CMD_WRITE_TO_WORKER
 
         if params:
